using System;
using System.Collections;

using SdlDotNet;
using Tao.OpenGl;

namespace Jumpers
{
	/// <summary>
	/// Simple particle system.
	/// </summary>
	public class ParticleSystem
	{
		private ArrayList m_particles = new ArrayList();

		public ParticleSystem()
		{
		}

		public void SpawnParticle( Vector2 pos, float speed )
		{
			m_particles.Add( new Particle( pos, speed ) );
		}

		public void Update()
		{
			int idx = 0;
			while ( idx < m_particles.Count )
			{
				Particle p = (Particle) m_particles[ idx ];
				bool ok = p.Update();

				if ( !ok )
					m_particles.RemoveAt( idx );
				else
					++idx;
			}
		}

		public void Draw()
		{
			Gl.glPointSize( 2.25f );

			Gl.glBegin( Gl.GL_POINTS );
			Gl.glColor3f( 0.8f, 0.1f, 0.1f );
			foreach ( Particle p in m_particles )
			{
				Gl.glVertex2f( p.pos.X, p.pos.Y );
			}
			Gl.glEnd();
		}
	}

	/// <summary>
	/// One particle.
	/// </summary>
	public class Particle
	{
		public Vector2 pos;
		public Vector2 vel;

		public Particle( Vector2 spos, float speed )
		{
			pos = spos;

			vel = new Vector2( Resources.Random( -1, 1 ), -1 );
			vel.Normalize();
			vel *= Resources.Random( 0.5f, 2.5f );
			vel *= speed;
		}

		public bool Update()
		{
			pos += vel;
			vel.Y += 0.1f;

			return ( pos.Y < 460 );
		}
	}
}
